@@ -4,7 +4,8 @@ from wtforms.validators import Regexp
 from hiddifypanel.models import  User,Domain,DomainType,StrConfig,ConfigEnum,get_hconfigs
 from wtforms.validators import Regexp,ValidationError
 from .adminlte import AdminLTEModelView
-from flask_babelex import gettext as _
+from flask_babelex import gettext as __
+from flask_babelex import lazy_gettext as _
 from hiddifypanel.panel import hiddify
 from flask import Markup
 
@@ -13,7 +14,7 @@ class DomainAdmin(AdminLTEModelView):
     edit_modal=True
     
     column_descriptions = dict(
-        # name=_'just for remembering',
+        domain=_("domain.description"),
         mode=_("Direct mode means you want to use your server directly (for usual use), CDN means that you use your server on behind of a CDN provider."),
         cdn_ip=_("config.cdn_forced_host.description"),
         # current_usage_GB="in GB"
@@ -22,10 +23,10 @@ class DomainAdmin(AdminLTEModelView):
     can_export = False
     form_args = {
     'domain': {
-        'validators': [Regexp(r'^([A-Za-z0-9\-\.]+\.[a-zA-Z]{2,})$',message=_("Should be a valid domain"))]
+        'validators': [Regexp(r'^([A-Za-z0-9\-\.]+\.[a-zA-Z]{2,})$',message=__("Should be a valid domain"))]
     },
     "cdn_ip":{
-        'validators':[Regexp(r"(^((25[0-5]|(2[0-4]|1\d|[1-9]|)\d).){3}(25[0-5]|(2[0-4]|1\d|[1-9]|)\d)$)|^([A-Za-z0-9\-\.]+\.[a-zA-Z]{2,})$",message=_("config.Invalid IP or domain"))]
+        'validators':[Regexp(r"(^((25[0-5]|(2[0-4]|1\d|[1-9]|)\d).){3}(25[0-5]|(2[0-4]|1\d|[1-9]|)\d)$)|^([A-Za-z0-9\-\.]+\.[a-zA-Z]{2,})$",message=__("Invalid IP or domain"))]
     }
     }
     column_list = ["domain","mode","domain_ip","cdn_ip"]
